==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/S3931108d1662baf3d3b7a912ca3c43fd.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































  
#ifdef  CRAY
 
#define void char
 
#endif
 
#ifdef R8
 
#define Se87fe8c1caebf777126fa33703b13a10         15                      
 
#define S508e67617e1b9fa688fe2a948f66d5ab     2.2204460492503131e-016 
 
#define S96cbf2908b38a2bcbf501c6b41811b75    53                      
 
#define S2e38920c6b0f577c81906d8deae2e80b         1.7976931348623158e+308 
 
#define Sc072502adaf94139b809212781d2c569  308                     
 
#define Sedfda5f43bcb0f3dcde708d18f23f113     1024                    
 
#define S6719d5599ea6657da3292b2176a92a76         2.2250738585072014e-308 
 
#define Sfcbe4cab932a548748c70aaca1e1d67a  -307                    
 
#define S49c213002b0c35361bc571dcec0c7dd4     -1021                   
 
#define S4a278d0c4f57baf23604caa62fe07e42       2                       
 
#define S775b09fcbc750080f7ccce7e78074329      0                       
 
#else
 
#define Se87fe8c1caebf777126fa33703b13a10         6                       
 
#define S508e67617e1b9fa688fe2a948f66d5ab     1.192092896e-07         
 
#define S266b118d3e5f4bfc71253f3e0e52e02e       0
 
#define S96cbf2908b38a2bcbf501c6b41811b75    24                      
 
#define S2e38920c6b0f577c81906d8deae2e80b         3.402823466e+38         
 
#define Sc072502adaf94139b809212781d2c569  38                      
 
#define Sedfda5f43bcb0f3dcde708d18f23f113     128                     
 
#define S6719d5599ea6657da3292b2176a92a76         1.175494351e-38         
 
#define Sfcbe4cab932a548748c70aaca1e1d67a  -37                     
 
#define S49c213002b0c35361bc571dcec0c7dd4     -125                    
 
#define Sf7719a3ae3e30d992a6be6dc14e4b675   0
 
#define S4a278d0c4f57baf23604caa62fe07e42       2                       
 
#define S775b09fcbc750080f7ccce7e78074329      0                       
 
#endif
 
#ifdef R8
 
#define S8cf125b0e31559ba75a9d9b4f818a554 double
 
#else
 
#define S8cf125b0e31559ba75a9d9b4f818a554 S546ade640b6edfbc8a086ef31347e768
 
#endif
 
#define S6dd4ee07e7811f17d2b1b33bf3b6f0c1  S6719d5599ea6657da3292b2176a92a76
 
#ifndef HUGE
 
#define HUGE  S2e38920c6b0f577c81906d8deae2e80b
 
#endif
 
#define S9b9c17e13f0e3dc9860a26e08b59b2a7 S508e67617e1b9fa688fe2a948f66d5ab
 
#define Sa60c6c694491d75b439073b8cb05b139   S2e38920c6b0f577c81906d8deae2e80b
  
#define S5d5cd46919fa987731fb2edefe0f2a0c  int
 
#ifdef I2
 
#define S3a53a40cdabadda0b0caf3141bed4a9c short int
 
#else
 
#define S3a53a40cdabadda0b0caf3141bed4a9c long int
 
#endif
  
#define S334aaf2f201f8632647fefeb9ab4fbb5(S10ae767291498cd374065ef10453c659)              (S10ae767291498cd374065ef10453c659 *) S07206044c944baa2ea23de1f47482824((unsigned) (1), (unsigned) sizeof(S10ae767291498cd374065ef10453c659))
 
#define Sa80865d11e6f142ba342b33fc8dffa71(S56a54c7029e3420c4490f842f1997d5a,S10ae767291498cd374065ef10453c659)      (S10ae767291498cd374065ef10453c659 *) S07206044c944baa2ea23de1f47482824((unsigned) (S56a54c7029e3420c4490f842f1997d5a), (unsigned) sizeof(S10ae767291498cd374065ef10453c659))
 
#define Scb920e98977f13ca124932170a436443(Sbe8f80182e0c983916da7338c2c1c040,S56a54c7029e3420c4490f842f1997d5a,S10ae767291498cd374065ef10453c659) (S10ae767291498cd374065ef10453c659 *) realloc(Sbe8f80182e0c983916da7338c2c1c040, (unsigned) (S56a54c7029e3420c4490f842f1997d5a)*sizeof(S10ae767291498cd374065ef10453c659))
  
#define MAX( S9dd4e461268c8034f5c8564e155c67a6, S415290769594460e2e485922904f345d )               ((S9dd4e461268c8034f5c8564e155c67a6 > S415290769594460e2e485922904f345d ) ? ( S9dd4e461268c8034f5c8564e155c67a6 ) : ( S415290769594460e2e485922904f345d ))
 
#define Sce31e2a082d17e038fcc6e3006166653( S9dd4e461268c8034f5c8564e155c67a6, S415290769594460e2e485922904f345d )               ((S9dd4e461268c8034f5c8564e155c67a6 < S415290769594460e2e485922904f345d ) ? ( S9dd4e461268c8034f5c8564e155c67a6 ) : ( S415290769594460e2e485922904f345d ))
 
#define S7d8a220d2262f9d6c658d549ee12cf2c(S9dd4e461268c8034f5c8564e155c67a6)                    ((S9dd4e461268c8034f5c8564e155c67a6 > S529e9e0beb5f85d1f132917c1a09860c ) ? ( S9dd4e461268c8034f5c8564e155c67a6 ) : ( -S9dd4e461268c8034f5c8564e155c67a6))
 
#define Sc48a365c0a15f8c01a4006d6a17da5be(S9dd4e461268c8034f5c8564e155c67a6,S415290769594460e2e485922904f345d)  ((S9dd4e461268c8034f5c8564e155c67a6>S529e9e0beb5f85d1f132917c1a09860c)?((S415290769594460e2e485922904f345d>=S529e9e0beb5f85d1f132917c1a09860c)?(S6d86bcdc87773d8bb8527c65ed349b97(S415290769594460e2e485922904f345d/S9dd4e461268c8034f5c8564e155c67a6)):(-S6d86bcdc87773d8bb8527c65ed349b97(-S415290769594460e2e485922904f345d/S9dd4e461268c8034f5c8564e155c67a6))):((S415290769594460e2e485922904f345d>=S529e9e0beb5f85d1f132917c1a09860c)?(S52f4c30c5dcae70e16d173aeb02b44da-S6d86bcdc87773d8bb8527c65ed349b97(-S415290769594460e2e485922904f345d/S9dd4e461268c8034f5c8564e155c67a6)):(-S52f4c30c5dcae70e16d173aeb02b44da+S6d86bcdc87773d8bb8527c65ed349b97(S415290769594460e2e485922904f345d/S9dd4e461268c8034f5c8564e155c67a6))))
  
#define  Sc03e84e2195c6b9c2fc36b548b5f1bc4      3
 typedef S8cf125b0e31559ba75a9d9b4f818a554 Sfb1b8c2e2fd04e6de0a2608396c166a2[Sc03e84e2195c6b9c2fc36b548b5f1bc4]; 
typedef S8cf125b0e31559ba75a9d9b4f818a554 (*S1b5b2818fd59c0a04b4f43ea9ec75030)(); typedef S5d5cd46919fa987731fb2edefe0f2a0c 
(*S9a7026a8d7a891d1e209c6b346b57c25)(); typedef char (*S8fd11dd170fd0262942aea685c02a52a)(); typedef 
S8cf125b0e31559ba75a9d9b4f818a554 *S807765384d9d5527da8848df14a4f02f; typedef S5d5cd46919fa987731fb2edefe0f2a0c 
*S93906ef9739c0fa6c30caee28845f03e; typedef char *S2a733ad7585d6d473825f40b08909e87;  
#define S56121cc37d7123e665c0f8317f17aa5b extern void
 
#define Sa97b2c144243b2b9d2c593ec268b62f5    S5d5cd46919fa987731fb2edefe0f2a0c
 
#define TRUE    (S5d5cd46919fa987731fb2edefe0f2a0c)1
 
#define FALSE   (S5d5cd46919fa987731fb2edefe0f2a0c)0
 
#define S52f4c30c5dcae70e16d173aeb02b44da   3.1415926535897931
 
#define S529e9e0beb5f85d1f132917c1a09860c  0.0000000000000000
 
#define Sbc21e6484530fc9d0313cb816b733396   1.0000000000000000
 
#define Se25524800989ebde09d7f9a3633368e9 Safa0ff8b27b87666a6bde87251c5fde7("%c",7)
 
#define S618441d41cce47dbcfd9bed6e5ff64e6   Safa0ff8b27b87666a6bde87251c5fde7("\n")
 
#define S1fd406685cbdee605d0a7bebed56fdb0   Safa0ff8b27b87666a6bde87251c5fde7("\f")
 
#define S9a231c14a3416b1055b8ffb960151aee(Sb2145aac704ce76dbe1ac7adac535b23)   for(Sb2145aac704ce76dbe1ac7adac535b23=0; Sb2145aac704ce76dbe1ac7adac535b23<80; Sb2145aac704ce76dbe1ac7adac535b23++)  Safa0ff8b27b87666a6bde87251c5fde7("\b")
 
#define Sa6f5350f5a2b25a96d66757f761ce65c(Sb2145aac704ce76dbe1ac7adac535b23)   for(Sb2145aac704ce76dbe1ac7adac535b23=0; Sb2145aac704ce76dbe1ac7adac535b23<79; Sb2145aac704ce76dbe1ac7adac535b23++)  Safa0ff8b27b87666a6bde87251c5fde7(" ")
 
#define S8a5c3c27d1382e2bd59773d9c98b7154  system("cls")
  
#define S17397db46d681ccf7e7eeb0e50b81db8   0
 
#define S0424e1530c7239c458999e32fdd711b0 1024
 
#define S52f1e315372b38db1b8f4e3666c4f721  (S4a8a08f09d37b73795649038408b5f33==' '||S4a8a08f09d37b73795649038408b5f33=='\t'||S4a8a08f09d37b73795649038408b5f33=='\n'||S4a8a08f09d37b73795649038408b5f33=='\\'||S4a8a08f09d37b73795649038408b5f33==';'||S4a8a08f09d37b73795649038408b5f33==','||S4a8a08f09d37b73795649038408b5f33=='~')
 
#define S24ba98dc16329ad66bf1a9abfeb19ff4         (S4a8a08f09d37b73795649038408b5f33==' '||S4a8a08f09d37b73795649038408b5f33=='\t'||S4a8a08f09d37b73795649038408b5f33=='\n'||S4a8a08f09d37b73795649038408b5f33=='\\'||S4a8a08f09d37b73795649038408b5f33==';')
 
#define Sb94b31b786135414e2b07e72347e9164         (S4a8a08f09d37b73795649038408b5f33==','||S4a8a08f09d37b73795649038408b5f33=='~')
 typedef char *S96d4cdff8ed57e93e3b3d843cffe3af7; 
#define Sfa301d27d4fe8f7aaf54cac11dda41a0()     (S96d4cdff8ed57e93e3b3d843cffe3af7 *) malloc(sizeof(S96d4cdff8ed57e93e3b3d843cffe3af7))
 
#define S44400f3a4b7f714e85ca8a556eae8349(S5cfdb867e96374c7883b31d6928cc4cb)  free(S5cfdb867e96374c7883b31d6928cc4cb)

==> sawmill6.5b3_crypt_src.tar.gz: sawmill-6.5b3/S3931108d1662baf3d3b7a912ca3c43fd.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































  
#ifdef  CRAY
 
#define void char
 
#endif
 
#ifdef R8
 
#define Se87fe8c1caebf777126fa33703b13a10         15                      
 
#define S508e67617e1b9fa688fe2a948f66d5ab     2.2204460492503131e-016 
 
#define S96cbf2908b38a2bcbf501c6b41811b75    53                      
 
#define S2e38920c6b0f577c81906d8deae2e80b         1.7976931348623158e+308 
 
#define Sc072502adaf94139b809212781d2c569  308                     
 
#define Sedfda5f43bcb0f3dcde708d18f23f113     1024                    
 
#define S6719d5599ea6657da3292b2176a92a76         2.2250738585072014e-308 
 
#define Sfcbe4cab932a548748c70aaca1e1d67a  -307                    
 
#define S49c213002b0c35361bc571dcec0c7dd4     -1021                   
 
#define S4a278d0c4f57baf23604caa62fe07e42       2                       
 
#define S775b09fcbc750080f7ccce7e78074329      0                       
 
#else
 
#define Se87fe8c1caebf777126fa33703b13a10         6                       
 
#define S508e67617e1b9fa688fe2a948f66d5ab     1.192092896e-07         
 
#define S266b118d3e5f4bfc71253f3e0e52e02e       0
 
#define S96cbf2908b38a2bcbf501c6b41811b75    24                      
 
#define S2e38920c6b0f577c81906d8deae2e80b         3.402823466e+38         
 
#define Sc072502adaf94139b809212781d2c569  38                      
 
#define Sedfda5f43bcb0f3dcde708d18f23f113     128                     
 
#define S6719d5599ea6657da3292b2176a92a76         1.175494351e-38         
 
#define Sfcbe4cab932a548748c70aaca1e1d67a  -37                     
 
#define S49c213002b0c35361bc571dcec0c7dd4     -125                    
 
#define Sf7719a3ae3e30d992a6be6dc14e4b675   0
 
#define S4a278d0c4f57baf23604caa62fe07e42       2                       
 
#define S775b09fcbc750080f7ccce7e78074329      0                       
 
#endif
 
#ifdef R8
 
#define S8cf125b0e31559ba75a9d9b4f818a554 double
 
#else
 
#define S8cf125b0e31559ba75a9d9b4f818a554 float
 
#endif
 
#define S6dd4ee07e7811f17d2b1b33bf3b6f0c1  S6719d5599ea6657da3292b2176a92a76
 
#ifndef HUGE
 
#define HUGE  S2e38920c6b0f577c81906d8deae2e80b
 
#endif
 
#define S9b9c17e13f0e3dc9860a26e08b59b2a7 S508e67617e1b9fa688fe2a948f66d5ab
 
#define Sa60c6c694491d75b439073b8cb05b139   S2e38920c6b0f577c81906d8deae2e80b
  
#define S5d5cd46919fa987731fb2edefe0f2a0c  int
 
#ifdef I2
 
#define S3a53a40cdabadda0b0caf3141bed4a9c short int
 
#else
 
#define S3a53a40cdabadda0b0caf3141bed4a9c long int
 
#endif
  
#define S334aaf2f201f8632647fefeb9ab4fbb5(S10ae767291498cd374065ef10453c659)              (S10ae767291498cd374065ef10453c659 *) S07206044c944baa2ea23de1f47482824((unsigned) (1), (unsigned) sizeof(S10ae767291498cd374065ef10453c659))
 
#define Sa80865d11e6f142ba342b33fc8dffa71(S56a54c7029e3420c4490f842f1997d5a,S10ae767291498cd374065ef10453c659)      (S10ae767291498cd374065ef10453c659 *) S07206044c944baa2ea23de1f47482824((unsigned) (S56a54c7029e3420c4490f842f1997d5a), (unsigned) sizeof(S10ae767291498cd374065ef10453c659))
 
#define Scb920e98977f13ca124932170a436443(Sbe8f80182e0c983916da7338c2c1c040,S56a54c7029e3420c4490f842f1997d5a,S10ae767291498cd374065ef10453c659) (S10ae767291498cd374065ef10453c659 *) realloc(Sbe8f80182e0c983916da7338c2c1c040, (unsigned) (S56a54c7029e3420c4490f842f1997d5a)*sizeof(S10ae767291498cd374065ef10453c659))
  
#define MAX( S9dd4e461268c8034f5c8564e155c67a6, S415290769594460e2e485922904f345d )               ((S9dd4e461268c8034f5c8564e155c67a6 > S415290769594460e2e485922904f345d ) ? ( S9dd4e461268c8034f5c8564e155c67a6 ) : ( S415290769594460e2e485922904f345d ))
 
#define Sce31e2a082d17e038fcc6e3006166653( S9dd4e461268c8034f5c8564e155c67a6, S415290769594460e2e485922904f345d )               ((S9dd4e461268c8034f5c8564e155c67a6 < S415290769594460e2e485922904f345d ) ? ( S9dd4e461268c8034f5c8564e155c67a6 ) : ( S415290769594460e2e485922904f345d ))
 
#define S7d8a220d2262f9d6c658d549ee12cf2c(S9dd4e461268c8034f5c8564e155c67a6)                    ((S9dd4e461268c8034f5c8564e155c67a6 > S529e9e0beb5f85d1f132917c1a09860c ) ? ( S9dd4e461268c8034f5c8564e155c67a6 ) : ( -S9dd4e461268c8034f5c8564e155c67a6))
 
#define Sc48a365c0a15f8c01a4006d6a17da5be(S9dd4e461268c8034f5c8564e155c67a6,S415290769594460e2e485922904f345d)  ((S9dd4e461268c8034f5c8564e155c67a6>S529e9e0beb5f85d1f132917c1a09860c)?((S415290769594460e2e485922904f345d>=S529e9e0beb5f85d1f132917c1a09860c)?(S6d86bcdc87773d8bb8527c65ed349b97(S415290769594460e2e485922904f345d/S9dd4e461268c8034f5c8564e155c67a6)):(-S6d86bcdc87773d8bb8527c65ed349b97(-S415290769594460e2e485922904f345d/S9dd4e461268c8034f5c8564e155c67a6))):((S415290769594460e2e485922904f345d>=S529e9e0beb5f85d1f132917c1a09860c)?(S52f4c30c5dcae70e16d173aeb02b44da-S6d86bcdc87773d8bb8527c65ed349b97(-S415290769594460e2e485922904f345d/S9dd4e461268c8034f5c8564e155c67a6)):(-S52f4c30c5dcae70e16d173aeb02b44da+S6d86bcdc87773d8bb8527c65ed349b97(S415290769594460e2e485922904f345d/S9dd4e461268c8034f5c8564e155c67a6))))
  
#define  Sc03e84e2195c6b9c2fc36b548b5f1bc4      3
 typedef S8cf125b0e31559ba75a9d9b4f818a554 Sfb1b8c2e2fd04e6de0a2608396c166a2[Sc03e84e2195c6b9c2fc36b548b5f1bc4]; 
typedef S8cf125b0e31559ba75a9d9b4f818a554 (*S1b5b2818fd59c0a04b4f43ea9ec75030)(); typedef S5d5cd46919fa987731fb2edefe0f2a0c 
(*S9a7026a8d7a891d1e209c6b346b57c25)(); typedef char (*S8fd11dd170fd0262942aea685c02a52a)(); typedef 
S8cf125b0e31559ba75a9d9b4f818a554 *S807765384d9d5527da8848df14a4f02f; typedef S5d5cd46919fa987731fb2edefe0f2a0c 
*S93906ef9739c0fa6c30caee28845f03e; typedef char *S2a733ad7585d6d473825f40b08909e87;  
#define S56121cc37d7123e665c0f8317f17aa5b extern void
 
#define Sa97b2c144243b2b9d2c593ec268b62f5    S5d5cd46919fa987731fb2edefe0f2a0c
 
#define TRUE    (S5d5cd46919fa987731fb2edefe0f2a0c)1
 
#define FALSE   (S5d5cd46919fa987731fb2edefe0f2a0c)0
 
#define S52f4c30c5dcae70e16d173aeb02b44da   3.1415926535897931
 
#define S529e9e0beb5f85d1f132917c1a09860c  0.0000000000000000
 
#define Sbc21e6484530fc9d0313cb816b733396   1.0000000000000000
 
#define Se25524800989ebde09d7f9a3633368e9 printf("%c",7)
 
#define S618441d41cce47dbcfd9bed6e5ff64e6   printf("\n")
 
#define S1fd406685cbdee605d0a7bebed56fdb0   printf("\f")
 
#define S9a231c14a3416b1055b8ffb960151aee(Sb2145aac704ce76dbe1ac7adac535b23)   for(Sb2145aac704ce76dbe1ac7adac535b23=0; Sb2145aac704ce76dbe1ac7adac535b23<80; Sb2145aac704ce76dbe1ac7adac535b23++)  printf("\b")
 
#define Sa6f5350f5a2b25a96d66757f761ce65c(Sb2145aac704ce76dbe1ac7adac535b23)   for(Sb2145aac704ce76dbe1ac7adac535b23=0; Sb2145aac704ce76dbe1ac7adac535b23<79; Sb2145aac704ce76dbe1ac7adac535b23++)  printf(" ")
 
#define S8a5c3c27d1382e2bd59773d9c98b7154  system("cls")
  
#define S17397db46d681ccf7e7eeb0e50b81db8   0
 
#define S0424e1530c7239c458999e32fdd711b0 1024
 
#define S52f1e315372b38db1b8f4e3666c4f721  (S4a8a08f09d37b73795649038408b5f33==' '||S4a8a08f09d37b73795649038408b5f33=='\t'||S4a8a08f09d37b73795649038408b5f33=='\n'||S4a8a08f09d37b73795649038408b5f33=='\\'||S4a8a08f09d37b73795649038408b5f33==';'||S4a8a08f09d37b73795649038408b5f33==','||S4a8a08f09d37b73795649038408b5f33=='~')
 
#define S24ba98dc16329ad66bf1a9abfeb19ff4         (S4a8a08f09d37b73795649038408b5f33==' '||S4a8a08f09d37b73795649038408b5f33=='\t'||S4a8a08f09d37b73795649038408b5f33=='\n'||S4a8a08f09d37b73795649038408b5f33=='\\'||S4a8a08f09d37b73795649038408b5f33==';')
 
#define Sb94b31b786135414e2b07e72347e9164         (S4a8a08f09d37b73795649038408b5f33==','||S4a8a08f09d37b73795649038408b5f33=='~')
 typedef char *S96d4cdff8ed57e93e3b3d843cffe3af7; 
#define Sfa301d27d4fe8f7aaf54cac11dda41a0()     (S96d4cdff8ed57e93e3b3d843cffe3af7 *) malloc(sizeof(S96d4cdff8ed57e93e3b3d843cffe3af7))
 
#define S44400f3a4b7f714e85ca8a556eae8349(S5cfdb867e96374c7883b31d6928cc4cb)  free(S5cfdb867e96374c7883b31d6928cc4cb)
